soupsieve: Modern CSS selector implementation for Beautiful Soup
================================================================

Description
-----------

Modern CSS selector implementation for Beautiful Soup

License
-------

Upstream Contact
----------------

https://pypi.org/project/soupsieve/

